function example(ex)

if nargin < 1, ex = 1; end

N = 11; % Number of gridpoints
L = 1; k1 = 2*pi/L; % Physical size of domain
x = L*(0:N-1)/N; y = x'; [xx,yy] = meshgrid(x,y);

switch ex
 % Examples 1 and 2 use the same cellular source, for q=0 and q=-1.
 % Since the source is an eigenfuntion of the Laplacian, the optimal
 % flow is the same for q=-1.
 case {1,2}
  src = cos(k1*xx).*cos(k1*yy) * 2/L;
  psi0 = sin(k1*xx).*sin(k1*yy) * 1/sqrt(2)/pi;
  kappa = .1; q = 1-ex;
 % Examples 3 and 4 use the same two-mode source, for q=0 and q=-1.
 % Since the source is not an eigenfuntion of the Laplacian, the optimal
 % flow is different for q=-1.
 case {3,4}
  src = (cos(k1*xx).*cos(k1*yy)+cos(3*k1*yy)+.25*sin(3*k1*yy)) * 4*sqrt(2)/5/L;
  psi0 = sin(k1*xx).*sin(k1*yy) * 1/sqrt(2)/pi;
  kappa = .1; q = 3-ex;
 case 5
  % Unmixing solution
  src = (cos(k1*xx) - .5).*sin(k1*yy) * 2*sqrt(2/3)/L;
  psi0 = sin(k1*xx).*sin(2*k1*yy) * 1/sqrt(5)/pi;
  scalefac = -N^2; % Set scale factor negative to minimize instead
  kappa = 1/4; q = 0;
end

if ~exist('scalefac'), scalefac = N^2; end

[psi,Effq] = velopt(psi0,src,kappa,q,L,scalefac);

fprintf(1,'Eff_%d=%f\n',q,Effq)

figure(1)
Nplot = 64; % Interpolate solution for plotting
psir = refine2(psi,Nplot); srcr = refine2(src,Nplot);
xplot = L*(0:Nplot-1)/Nplot; yplot = xplot';
imagesc(xplot,yplot,srcr), colorbar, hold on
contour(xplot,yplot,psir,10,'EdgeColor','k'), hold off
